.. _api:

API Class
=========

Falcon's API class is a WSGI "application" that you can host with any
standard-compliant WSGI server.

.. code:: python

    import falcon

    api = application = falcon.API()

.. autoclass:: falcon.API
    :members:

.. autoclass:: falcon.RequestOptions
    :members:


